==> pax-jdbc-config-1.4.4-sources.jar: org/ops4j/pax/jdbc/config/impl/PoolingWrapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.ops4j.pax.jdbc.config.impl;

import java.sql.Driver;
import java.sql.SQLException;
import java.util.Properties;

import javax.sql.ConnectionPoolDataSource;
import javax.sql.DataSource;
import javax.sql.XADataSource;

import org.ops4j.pax.jdbc.pool.common.PooledDataSourceFactory;
import org.osgi.service.jdbc.DataSourceFactory;

public class PoolingWrapper implements DataSourceFactory {
    
    private PooledDataSourceFactory pdsf;
    private DataSourceFactory dsf;

    public PoolingWrapper(PooledDataSourceFactory pdsf, DataSourceFactory dsf) {
        this.pdsf = pdsf;
        this.dsf = dsf;
    }

    @Override
    public DataSource createDataSource(Properties props) throws SQLException {
        return pdsf.create(dsf, props);
    }

    @Override
    public ConnectionPoolDataSource createConnectionPoolDataSource(Properties props) throws SQLException {
        return dsf.createConnectionPoolDataSource(props);
    }

    @Override
    public XADataSource createXADataSource(Properties props) throws SQLException {
        return dsf.createXADataSource(props);
    }

    @Override
    public Driver createDriver(Properties props) throws SQLException {
        return dsf.createDriver(props);
    }

}

==> pax-jdbc-config-1.5.7-sources.jar: org/ops4j/pax/jdbc/config/impl/PoolingWrapper.java <==
/*
 * Copyright 2021 OPS4J.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ops4j.pax.jdbc.config.impl;

import java.sql.Driver;
import java.sql.SQLException;
import java.util.Properties;

import javax.sql.ConnectionPoolDataSource;
import javax.sql.DataSource;
import javax.sql.XADataSource;

import org.ops4j.pax.jdbc.pool.common.PooledDataSourceFactory;
import org.osgi.service.jdbc.DataSourceFactory;

public class PoolingWrapper implements DataSourceFactory {
    
    private final PooledDataSourceFactory pdsf;
    private final DataSourceFactory dsf;

    public PoolingWrapper(PooledDataSourceFactory pdsf, DataSourceFactory dsf) {
        this.pdsf = pdsf;
        this.dsf = dsf;
    }

    @Override
    public DataSource createDataSource(Properties props) throws SQLException {
        return pdsf.create(dsf, props);
    }

    @Override
    public ConnectionPoolDataSource createConnectionPoolDataSource(Properties props) throws SQLException {
        return dsf.createConnectionPoolDataSource(props);
    }

    @Override
    public XADataSource createXADataSource(Properties props) throws SQLException {
        return dsf.createXADataSource(props);
    }

    @Override
    public Driver createDriver(Properties props) throws SQLException {
        return dsf.createDriver(props);
    }

}
